@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from PyQt4.QtCore import QAbstractListModel, pyqtSlot
+from PyQt4.QtCore import QAbstractListModel
 from PyQt4.Qt import Qt
 from common import QIconCache
 
@@ -10,7 +10,6 @@ class BookmarkListModel(QAbstractListModel):
         self.server = server
         self.reset()
 
-    @pyqtSlot()
     def reset(self):
         self.objs = self.server.pullLocks()
         QAbstractListModel.reset(self)
