@@ -4,7 +4,7 @@ import os
 from time import sleep
 from config import config
 
-from PyQt4.QtCore import QModelIndex, QString, Qt, pyqtSlot, pyqtSignal, \
+from PyQt4.QtCore import QModelIndex, QString, Qt, pyqtSignal, \
     QSize, QTimer, QThread, QAbstractItemModel
 from PyQt4.QtGui import QSortFilterProxyModel, QTableView, QAbstractItemView, \
     QToolBar, QIcon, QPlainTextEdit, QHBoxLayout, QFileDialog, QMessageBox, \
@@ -55,17 +55,14 @@ class StringsetProxyModel(QSortFilterProxyModel):
                 return self.filterUntranslated
         return False
 
-    @pyqtSlot(bool)
     def setFilterTranslated(self, flag):
         self.filterTranslated = flag
         self.invalidate()
 
-    @pyqtSlot(bool)
     def setFilterFuzzy(self, flag):
         self.filterFuzzy = flag
         self.invalidate()
 
-    @pyqtSlot(bool)
     def setFilterUntranslated(self, flag):
         self.filterUntranslated = flag
         self.invalidate()
@@ -127,17 +124,14 @@ class FilePushThread(QThread):
         self.finish.emit()
 
 class FileView(QCustomWindow):
-    @pyqtSlot(QModelIndex)
     def editString(self, index):
         self.modified = True
 #        if isinstance(self.model, QSortFilterProxyModel):
 #            index = self.model.mapToSource(index)
-        print "Going to edit string... model:", self.source_model
         win = StringView(self.model, index,
             parent=self)
         win.show()
 
-    @pyqtSlot()
     def fileSave(self, push=True, unlock=True, close=True):
         if isinstance(self.file_model, RemoteFileModel):
             self.pd = QProgressDialog(parent=self)
@@ -161,13 +155,11 @@ class FileView(QCustomWindow):
                 QMaemo5InformationBox.information(self, 
                     "<font color='black'>%s saved</font>" % self.file_model.title())
 
-    @pyqtSlot()
     def fileSaveAs(self):
         filename = QFileDialog.getSaveFileName(
             self, caption="Save file as...",
             filter=QString("Gettext PO (*.po)"))
 
-    @pyqtSlot()
     def fileOpen(self):
         filename = QFileDialog.getOpenFileName(
             self, caption="Open translation file...",
@@ -177,20 +169,17 @@ class FileView(QCustomWindow):
 #            self.fileLoad(LocalFileModel(filename))
         self.modified = False
 
-    @pyqtSlot()
     def helpAbout(self):
         QMessageBox.about(
             self,
             self.tr("About mobile traslator"),
             HELP_ABOUT)
 
-    @pyqtSlot(str, int)
     def setProgress(self, text, value):
         self.pd.setValue(value)
         self.pd.setLabelText(text)
         sleep(0.05)
 
-    @pyqtSlot(QAbstractItemModel)
     def setSourceModel(self, source_model):
         self.source_model = source_model
         if self.model:
@@ -213,7 +202,6 @@ class FileView(QCustomWindow):
                 self.model.setFilterUntranslated)
         self.tableview.setEnabled(True)
 
-    @pyqtSlot(bool)
     def editFind(self, checked):
         """
         Open search string dialog and use the string in lowercase to filter 
@@ -228,7 +216,6 @@ class FileView(QCustomWindow):
         else:
             self.model.setFilterFixedString("")
 
-    @pyqtSlot()
     def forceClose(self):
         self.force_close = True
         self.close()
