@@ -276,8 +276,8 @@ class ServerModel(QObject):
             if m:
                 for key, value in m.groupdict().iteritems():
                     if not re.match(self.RE_ACCOUNT_FIELD_BLANK, value):
-                        d[key] = value
-                        #d[key] = value.decode('utf-8')
+#                        d[key] = value
+                        d[key] = u"%s" % value.decode('utf-8')
             else:
                 raise TransifexInvalidProfile()
         return d
